@@ -15,14 +15,17 @@ class FfmpegProcess:
         Accepts an optional ffmpeg_loglevel parameter to set the value of FFmpeg's -loglevel argument.
         """
         self._command = command
+        index_of_filepath = self._command.index("-i") + 1
+        self._filepath = self._command[index_of_filepath]
+    
         self._can_get_duration = True
 
         try:
-            duration_secs = float(probe(filepath)["format"]["duration"])
+            duration_secs = float(probe(self._filepath)["format"]["duration"])
         except Exception:
             self._can_get_duration = False
 
-        self._ffmpeg_args = command + ["-loglevel", ffmpeg_loglevel]
+        self._ffmpeg_args = self._command + ["-loglevel", ffmpeg_loglevel]
 
         if self._can_get_duration:
             # pipe:1 sends the progress to stdout. See https://stackoverflow.com/a/54386052/13231825
@@ -38,9 +41,6 @@ class FfmpegProcess:
         Progress: 25% | Speed: 22.3x | ETA: 1m 33s
         """
 
-        index_of_filepath = self._command.index("-i") + 1
-        filepath = self._command[index_of_filepath]
-
         if ffmpeg_output_file is None:
             os.makedirs("ffmpeg_output", exist_ok=True)
             ffmpeg_output_file = os.path.join("ffmpeg_output", f"[{Path(filepath).name}].txt")
